import PageContent from '@/components/PageContent';
import PageTitle from '@/components/PageTitle';
import {
  queryInventoryList,
  queryStoreList,
} from '@/services/StorageManagement';
import { useParams, useRequest } from '@umijs/max';
import { Table } from 'antd';
import dayjs from 'dayjs';
import { useEffect } from 'react';
import { PageType } from '.';
const SparePartDetail = () => {
  const { projectId, type } = useParams();
  const titles = ['入库详情', '出库详情', '报废详情', '库存详情'];

  const params = {
    type: Number(type),
    project_id: Number(projectId),
    check_result: 0,
    category_id: 0,
    start_time: '',
    end_time: '',
    name: '',
  };
  const paramsExit = {
    category_id: 0,
    name: '',
    warning_state: 0,
    project_id: Number(projectId),
  };

  useEffect(() => {
    type !== PageType.existing ? run(params) : runExist(paramsExit);
  }, [type]);
  const { data, run, loading } = useRequest((data) => queryStoreList(data), {
    manual: true,
  });

  const {
    data: dataExist,
    loading: loadingExist,
    run: runExist,
  } = useRequest((data) => queryInventoryList(data), {
    manual: true,
  });
  const columns = [
    {
      title: '仓储类型',
      dataIndex: 'category_name',
      key: 'category_name',
      align: 'center',
    },
    {
      title: '名称',
      dataIndex: 'name',
      key: 'name',
      align: 'center',
    },
    {
      title: '型号',
      dataIndex: 'model_number',
      key: 'model_number',
      align: 'center',
    },
  ];
  const columnsIn = [
    ...columns,
    {
      title: '入库数量',
      // dataIndex: 'amount',
      // key: 'amount',
      align: 'center',
      render: (recode) => (
        <div>
          {recode.amount}
          {recode.unit}
        </div>
      ),
    },
    {
      title: '入库日期',
      dataIndex: 'create_time',
      key: 'create_time',
      align: 'center',
      render: (time) => dayjs(time).format('YYYY-MM-DD'),
    },
    {
      title: '入库人',
      dataIndex: 'user_name',
      key: 'user_name',
      align: 'center',
    },
  ];
  const columnsOut = [
    ...columns,
    {
      title: '出库数量',
      // dataIndex: 'amount',
      // key: 'amount',
      align: 'center',
      render: (recode) => (
        <div>
          {recode.amount}
          {recode.unit}
        </div>
      ),
    },
    {
      title: '出库日期',
      dataIndex: 'create_time',
      key: 'create_time',
      align: 'center',
      render: (time) => dayjs(time).format('YYYY-MM-DD'),
    },
    {
      title: '出库人',
      dataIndex: 'user_name',
      key: 'user_name',
      align: 'center',
    },
    {
      title: '领用人',
      dataIndex: 'recipient_user_name',
      key: 'recipient_user_name',
      align: 'center',
    },
  ];
  const columnsScrap = [
    ...columns,
    {
      title: '报废信息',
      dataIndex: 'desc',
      key: 'desc',
      align: 'center',
    },
    {
      title: '报废数量',
      // dataIndex: 'amount',
      // key: 'amount',
      align: 'center',
      render: (recode) => (
        <div>
          {recode.amount}
          {recode.unit}
        </div>
      ),
    },
    {
      title: '经办人',
      dataIndex: 'user_name',
      key: 'user_name',
      align: 'center',
    },
    {
      title: '报废日期',
      dataIndex: 'create_time',
      key: 'create_time',
      align: 'center',
      render: (time) => dayjs(time).format('YYYY-MM-DD'),
    },
    {
      title: '图片',
      dataIndex: 'images',
      align: 'center',
      render: (images) => {
        if (images) {
          const imgs = JSON.parse(images);
          const setData = imgs.map((img) => {
            return { src: img };
          });
          return (
            <>
              <a
                onClick={() => {
                  console.log(imgs[0]);
                  return Zmage.browsing({
                    set: setData,
                  });
                }}
              >
                查看
              </a>
            </>
          );
        } else {
          return <div>暂无图片</div>;
        }
      },
    },
  ];
  const columnsExit = [
    {
      title: '类型',
      dataIndex: 'category_name',
      key: 'category_name',
      align: 'center',
    },
    {
      title: '名称',
      dataIndex: 'name',
      key: 'name',
      align: 'center',
    },
    {
      title: '型号',
      dataIndex: 'model_number',
      key: 'model_number',
      align: 'center',
    },
    {
      title: '在库',
      align: 'center',
      render: (record) => (
        <div>
          {record.in_amount - record.out_amount - record.scrap_amount}
          {record.unit}
        </div>
      ),
    },
    {
      title: '入库',
      align: 'center',
      render: (recode) => (
        <div>
          {recode.in_amount}
          {recode.unit}
        </div>
      ),
    },
    {
      title: '出库',
      align: 'center',
      render: (recode) => (
        <div>
          {recode.out_amount}
          {recode.unit}
        </div>
      ),
    },
    {
      title: '报废',
      align: 'center',
      render: (recode) => (
        <div>
          {recode.scrap_amount}
          {recode.unit}
        </div>
      ),
    },
    {
      title: '预警状态',
      dataIndex: 'warning_state',
      align: 'warning_state',
      align: 'center',
      render: (warn) => {
        return warn == 2 ? (
          <div style={{ color: 'red' }}>报警</div>
        ) : (
          <div>正常</div>
        );
      },
    },
    {
      title: '预警内容',
      dataIndex: 'warning_content',
      key: 'warning_content',
      align: 'center',
    },
  ];
  const columnsList = [columnsIn, columnsOut, columnsScrap, columnsExit];

  return (
    <PageContent closeable={false}>
      <PageTitle children={titles[type]} returnable />
      {type !== PageType.existing ? (
        <Table
          loading={loading}
          style={{ marginTop: '10px' }}
          dataSource={data}
          columns={columnsList[type]}
          pagination={false}
        />
      ) : (
        <Table
          loading={loadingExist}
          style={{ marginTop: '10px' }}
          dataSource={dataExist}
          columns={columnsList[type]}
          pagination={false}
        />
      )}
    </PageContent>
  );
};
export default SparePartDetail;
